# ims-lti-py

Python port of the useful [ims-lti](https://github.com/instructure/ims-lti) Ruby library. Makes integrating with LTI pretty easy.

## Installation

TODO

## Dependencies

 * [lxml](https://github.com/lxml/lxml)
 * [python-oath2](https://github.com/simplegeo/python-oauth2)

## Usage

TODO

## Testing
ims-lti-py unit tests can be run with the [nose](http://readthedocs.org/docs/nose/en/latest/) Python library. Once installed, just run

    nosetests tests/
